@@ -11,7 +11,8 @@ genom_factory = lambda: factory.generate
 insolation_meter = StaticInsolation
 address_provider = address.SequenceAddressProvider
 size = lambda: 3
-
+cell_capacity = lambda: 1
+algae_growth_probability = lambda: 0.3
 
 reproduction_minimum = lambda: 10
 movement_energy = lambda: 0.25
