@@ -1,11 +1,6 @@
 from __future__ import print_function
-from compiler.ast import flatten
 from datetime import datetime
-import itertools
 import logging
-from subprocess import Popen
-
-import matplotlib.pyplot as plt
 
 from pyage.core.inject import Inject
 from pyage.core.statistics import Statistics
@@ -15,75 +10,6 @@ from pyage_forams.solutions.foram import Foram
 logger = logging.getLogger(__name__)
 
 
-class PlottingStatistics(Statistics):
-    @Inject("environment")
-    def __init__(self):
-        super(PlottingStatistics, self).__init__()
-        self.prefix = datetime.now().strftime("%Y%m%d_%H%M%S")
-
-    def update(self, step_count, agents):
-        self.plot(self.environment.grid, step_count, agents)
-
-    def summarize(self, agents):
-        pass
-        # cmd = "convert -loop 0 -delay 50 /tmp/pyage-step-*-%s.png animation.gif && rm /tmp/pyage-step-*-%s.png" % (
-        # self.prefix, self.prefix)
-        # Popen(cmd, shell=True)
-
-    def plot(self, grid, step, agents):
-        plt.title("step %d %s" % (step, agents[0].get_address()))
-
-        forams = []
-        for (i, row) in enumerate(grid):
-            for (j, cell) in enumerate(row):
-                if not cell.is_empty():
-                    forams.append((i, j))
-                    self._draw_chambers(grid, i, j)
-
-        x = len(grid)
-        y = len(grid[0])
-
-        self._draw_forams(forams, grid)
-        self._draw_algae(grid, x, y)
-        self._draw_grid(x, y)
-
-        plt.savefig("/tmp/pyage-step-%07d-%s.png" % (step, self.prefix))
-        plt.close()
-
-    @staticmethod
-    def _draw_forams(forams, grid):
-        plt.scatter([c[0] for c in forams],
-                    [c[1] for c in forams],
-                    marker='o',
-                    s=[200.0 / len(grid) * grid[i][j].foram.energy for (i, j) in forams],
-                    c=['red' for _ in forams])
-
-    @staticmethod
-    def _draw_grid(x, y):
-        plt.xticks([i - 0.5 for i in range(x + 1)], [])
-        plt.yticks([i - 0.5 for i in range(y + 1)], [])
-        plt.ticklabel_format()
-        plt.xlim([-0.5, x - 0.5])
-        plt.ylim([-0.5, y - 0.5])
-        plt.grid()
-
-    @staticmethod
-    def _draw_algae(grid, x, y):
-        pts = itertools.product(range(x), range(y))
-        plt.scatter(*zip(*pts), marker='*',
-                    s=[1000.0 / x * grid[i][j].get_algae() for i in range(x) for j in range(y)], color='blue',
-                    alpha=0.5)
-
-    @staticmethod
-    def _draw_chambers(grid, i, j):
-        plt.annotate(
-            grid[i][j].foram.chambers,
-            xy=(i, j), xytext=(-5, 5),
-            textcoords='offset points', ha='right', va='bottom',
-            bbox=dict(boxstyle='round,pad=0.2', fc='yellow', alpha=0.5),
-            arrowprops=dict(arrowstyle='->', connectionstyle='arc3,rad=0'))
-
-
 class CsvStatistics(Statistics):
     @Inject("environment")
     def __init__(self, interval=1, filename=None):
@@ -150,11 +76,11 @@ class PsiStatistics(Statistics):
 
     def _get_entry(self, x, y, z, step):
         cell = self.environment.grid[x][y][z]
-        if cell.is_empty() and cell.algae == 0:
+        if cell.is_empty() and cell._algae == 0:
             return None
-        return map(float, [x, y, z] + [0 if cell.is_empty() else cell.foram.chambers,
-                                       0 if cell.is_empty() else cell.foram.energy,
-                                       cell.algae,
+        return map(float, [x, y, z] + [0 if cell.is_empty() else next(iter(cell.forams)).chambers,
+                                       0 if cell.is_empty() else next(iter(cell.forams)).energy,
+                                       cell._algae,
                                        self.insolation_meter.get_insolation(cell, step)])
 
     def _add_header(self, f, cells_count):
